#
# spec file for package ghc-reflection
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name reflection
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.1.8
Release:        1.1
Summary:        Reifies arbitrary terms into types that can be reflected back into terms
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
%endif

%description
This package addresses the /configuration problem/ which is propagating
configurations that are available at run-time, allowing multiple configurations
to coexist without resorting to mutable global variables or
'System.IO.Unsafe.unsafePerformIO'.

That package is an implementation of the ideas presented in the paper
"Functional Pearl: Implicit Configurations" by Oleg Kiselyov and Chung-chieh
Shan (<http://okmij.org/ftp/Haskell/tr-15-04.pdf original paper>).
However, the API has been streamlined to improve performance.

There are a handful of tutorials on how to use this library:

* Austin Seipp's tutorial
<https://www.schoolofhaskell.com/user/thoughtpolice/using-reflection Reflecting
values to types and back> provides a summary of the approach taken by this
library, along with more motivating examples.

* Arnaud Spiwack's tutorial
<https://www.tweag.io/posts/2017-12-21-reflection-tutorial.html All about
reflection> explains how to use this library.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown examples

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat May  4 2024 Peter Simons <psimons@suse.com>
- Update reflection to version 2.1.8.
  [#] 2.1.8 [2024.05.04]
  * Fix a memory leak in `reifyTypeable`.
* Sat Sep 30 2023 Peter Simons <psimons@suse.com>
- Update reflection to version 2.1.7 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
- Drop obsolete code to remove +x permission from data files.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Feb 28 2023 Peter Simons <psimons@suse.com>
- Update reflection to version 2.1.7.
  [#] 2.1.7 [2023.02.28]
  * When building with `base-4.18` (GHC 9.6) or later, implement `reifyNat` and
    `reifySymbol` using the API provided by `GHC.TypeLits` instead of resorting
    to `unsafeCoerce`.
* Tue Feb 15 2022 Peter Simons <psimons@suse.com>
- Update copyright header in the spec file.
* Fri Feb 11 2022 Peter Simons <psimons@suse.com>
- Make sure installed text files have no +x flag.
* Tue Nov 16 2021 psimons@suse.com
- Update reflection to version 2.1.6 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Sep  7 2021 Ondřej Súkup <mimi.vx@gmail.com>
- make rpmlint happy
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Update reflection to version 2.1.6.
  [#] 2.1.6 [2020.05.16]
  * Fix a bug in which `give` (and possibly `reify`, `reifyNat`, and
    `reifySymbol`) could be unsoundly inlined by GHC 8.10 or older to produce
    incorrect runtime results.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Aug 28 2019 psimons@suse.com
- Update reflection to version 2.1.5.
  [#] 2.1.5 [2019.08.27]
  * Fix a bug in which `reifyNat` would yield incorrect results for very large
    `Integer`s on GHC 8.2 or later.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Thu Aug  2 2018 psimons@suse.com
- Add reflection at version 2.1.4.
